@@ -1,16 +1,15 @@
-pub mod interpreter;
-pub mod operators;
-pub mod value;
+/// Python library for mangle
+/// This provides bindings for evaluating mangle code from python
 
-use crate::interpreter::Interpreter;
-use pyo3::prelude::*;
+use mangle::interpreter::Interpreter;
 use pyo3::exceptions::PyValueError;
+use pyo3::prelude::*;
 
 /// Evaluates string as mangle code
 #[pyfunction]
 fn eval(line: String) -> PyResult<String> {
     let mut interpreter = Interpreter::new(' ');
-    match interpreter.evalline(&line) {
+    match interpreter.eval_line(&line) {
         Ok(result) => Ok(result),
         Err(err) => Err(PyValueError::new_err(format!("{}", err))),
     }
